BlobByteSource class final
A browser Blob-backed random-access byte source.
- Implemented types
Constructors
- BlobByteSource(Blob _blob, {int chunkSize = 4 * 1024 * 1024})
-
Creates a source that reads the
Blobin chunks up tochunkSize.
Properties
- chunkSize → int
-
Maximum number of bytes requested from the
Blobin a single slice.final - hashCode → int
-
The hash code for this object.
no setterinherited
-
length
→ Future<
int> -
Total number of bytes available from the source.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
read(
ByteRange range) → Future< Uint8List> -
Reads exactly the bytes covered by
range.override -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited